@@ -58,15 +58,12 @@ class MultipleThings:
             'title': thing.title
         }))
 
-    async def remove_thing(self, thing):
-        self.things.update({thing.id: thing})
-        del self.things[thing.id]
+    async def remove_thing(self, thing_id):
+        del self.things[thing_id]
         server = self.things.get('urn:webthing:server')
 
         await server.add_event(DeviceRemoveEvent({
-            '@type': thing.type,
-            'id': thing.id,
-            'title': thing.title
+            'id': thing_id,
         }))
 
 
